=====================================
 ``django_celery_monitor.managers``
=====================================

.. contents::
    :local:
.. currentmodule:: django_celery_monitor.managers

.. automodule:: django_celery_monitor.managers
    :members:
